import React, { useEffect, useState } from 'react';
import { BrowserRouter as Router } from 'react-router-dom';
import styled from 'styled-components';
import Footer from './components/Footer';
import Header from './components/Header';
import MainRouting from './components/MainRouting';
import UserContext, { IProfile } from './context/UserContext';

const Container = styled.div`
  height: 100%;
  display: flex;
  flex-direction: column;
  justify-content: space-between;
`;

const MainContent = styled.div`
  height: 100%;
`;

function App() {
  const [user, setUser] = useState({ loggedIn: false, profile: {} as IProfile });

  useEffect(() => {
    fetch('/api/v1/users/me')
      .then((response) => {
        if (!response.ok) return false;
        return response.json();
      })
      .then((profile) => {
        if (profile) {
          setUser({ loggedIn: true, profile });
        }
      });
  }, []);

  return (
    <UserContext.Provider value={user}>
      <Router>
        <Container>
          <Header />
          <MainContent>
            <MainRouting />
          </MainContent>
          <Footer />
        </Container>
      </Router>
    </UserContext.Provider>
  );
}

export default App;
